@@ -49,4 +49,4 @@ def read_csv(file_name: str) -> pd.DataFrame:
   first_lines = read_first_n_lines(file_name, 4)
   delimiter = detect_delimiter(first_lines)
   print(f"delimiter used: {delimiter}")
-  return pd.read_csv(file_name, delimiter=delimiter, dtype=str, engine='python', encoding='cp437')
\ No newline at end of file
+  return pd.read_csv(file_name, delimiter=delimiter, dtype=str, engine='python', encoding='cp437', index_col=False)
\ No newline at end of file
